
% Syntax:
% [theta,ISPdB] = DASB_ISPdB(M,aR);
%
% This MATLAB function simulates a Delay And Sum Beamformer. 
% It obtains the Incident Signal Power as a function of the 
% angle of arrival, theta.
%
% Input:
% M     - number of receivers in the array
% aR    - sample covariance matrix
%
% Output:
% theta - angle of arrival, theta (degrees -90 to +90)
% ISPdB - Incident Signal Power (dB)
%
%
% EXAMPLE1:
%
% M = 10;


function [theta,ISPdB] = DASB_ISPdB(M,aR);

beta = 1; 
% When beta = 1, NCCB becomes the DAS beamformer, and hence, it 
% uses the assumed array steering vector divided by M as the 
% weight vector.

i = 1;
ISP = zeros(1,241);

for theta = -60+90:1/2:60+90,
   
    theta = theta*pi/180;
    
    a = ones(M,1);
    for rec = 1:M,
        a(rec) = exp(-j*(rec-1)*pi*cos(theta));
    end
    
    w = a./M;
    wct = w';
    
    % Incident Signal Power:
    ISP(i) = wct*aR*w;
    
    i = i + 1;
    
end

theta = -60:1/2:60;
ISPdB = 10*log10( real(ISP) );

% -------------------------------------------------------------
