
% Syntax:
% [theta,ISPdB] = SCB_ISPdB(M,aR);
%
% This MATLAB function simulates a Standard Capon Beamformer. 
% It obtains the Incident Signal Power as a function of the 
% angle of arrival, theta.
%
% Input:
% M     - number of receivers in the array
% aR    - sample covariance matrix
%
% Output:
% theta - angle of arrival, theta (degrees -90 to +90)
% ISPdB - Incident Signal Power (dB)
%
%
% EXAMPLE1:
%
% M = 10;


function [theta,ISPdB] =  SCB_ISPdB(M,aR);

% Compute the eigendecomposition of R (or, in practice, of ^R):
[U,Gamma,V] = svd(aR);
Uct = U';

% We know that R^(-1) = U*(1/Gamma)*U'.
R_1 = U*diag(1./diag(Gamma))*Uct;

i = 1;
ISP = zeros(1,241);

for theta = -60+90:1/2:60+90,
   
    theta = theta*pi/180;
    
    a = ones(M,1);
    for rec = 1:M,
        a(rec) = exp(-j*(rec-1)*pi*cos(theta));
    end
    
    act = a';
    
    % Incident Signal Power:
    ISP(i) = 1/(act*R_1*a);
    
    i = i + 1;
    
end

theta = -60:1/2:60;
ISPdB = 10*log10( real(ISP) );

% -------------------------------------------------------------
