
% Syntax:
% aa = aassumed(var,a);
%
% This MATLAB function obtains the real array manifold vector. 
% Each element of the steering vector for each incident signal 
% is perturbed with a zero-mean circularly symmetric complex 
% Gaussian random normalized variable.
%
% Input:
% var   - variance of the white Gaussian error produced in the 
%         array
% a     - array manifold vector (theoretical one)
%
% Output:
% aa    - array manifold vector (real one)
%
% EXAMPLE1:
%
% var = 0.06;


function aa = aassumed(var,a);

[M,n] = size(a);
% M - number of sensors.
% n - number of signals.

z = sqrt(var)*( randn(M,n) + j*randn(M,n) );

aint = a + z;

aa = aint./norm(aint).*sqrt(M);

% -------------------------------------------------------------
